/*
This program is confidential and proprietary to MRJ Technology Solutions
and may not be reproduced, published or disclosed to others without
written authorization from MRJ.

Copyright (c) 1998 MRJ Technology Solutions, Inc. All Rights Reserved.

This program is derived from prior work some of which was originally
written as a joint project between the Numerical Aerospace Simulation
(NAS) Systems Division of NASA Ames Research Center and the National
Energy Research Supercomputer Center (NERSC) of Lawrence Livermore
National Laboratory.
*/
/*
 * credential.h - header file for default authentication system provided
 *	with PBS.  
 *
 * Other Requrired Header Files:
 *	"portability.h"
 *	"libpbs.h"
 *
 */

/* the credential as decrypted by the server */

struct credential {
	time_t timestamp;
	int    type;		/* see BATCH-types.h */
	char   username[PBS_MAXUSER];
	char   hostname[PBS_MAXHOSTNAME];
};

/*
 * a full ticket (credential) as passed from the client to the server
 * is of the following size: 8 for the pbs_iff key + 8 for the timestamp +
 * space for user and host name rounded up to multiple of 8 which is the
 * sub-credential size
 */
#define PBS_KEY_SIZE	 8
#define PBS_TIMESTAMP_SZ 8
#define PBS_SUBCRED_SIZE ((PBS_MAXUSER + PBS_MAXHOSTNAME + 7) / 8 * 8)
#define PBS_SEALED_SIZE (PBS_SUBCRED_SIZE + PBS_TIMESTAMP_SZ)
#define PBS_TICKET_SIZE (PBS_KEY_SIZE + PBS_SEALED_SIZE)

/*
 * a sealed ticket as produced by the server
 */
struct sealed_ticket {
	char timestamp[PBS_TIMESTAMP_SZ];
	char subcred[PBS_SUBCRED_SIZE];
};


#define CREDENTIAL_LIFETIME  3600
#define CREDENTIAL_TIME_DELTA 300

extern void break_cred A_((char key[PBS_KEY_SIZE], char *ticket, int size, struct credential *pcred));
extern int  get_credent A_((char *server,unsigned int port,char **credential));
extern int  make_sealed A_((char key[PBS_KEY_SIZE], char *subcred, int size, char **ticket));
extern void make_svr_key A_((char key[PBS_KEY_SIZE]));
extern int  make_subcred A_((char key[PBS_KEY_SIZE], char *user, char **subcred));
